@@ -199,7 +199,7 @@ module Pipe_writer (Data : DATA) = struct
      transport. *)
   let flushed (_ : t) = Deferred.unit
   let ready_to_write = flushed
-  let sent_result x : _ Send_result.t = Sent x
+  let sent_result x ~bytes : _ Send_result.t = Sent { result = x; bytes }
 
   let check_closed (t : t) f =
     if not (Pipe.is_closed t.pipe) then f () else Send_result.Closed
@@ -213,18 +213,19 @@ module Pipe_writer (Data : DATA) = struct
     check_closed t (fun () ->
       let buf = Bin_prot.Utils.bin_dump ~header:true writer x in
       let data = Data.of_bigstring buf in
-      incr_bytes_written t (Data.length data);
+      let len = Data.length data in
+      incr_bytes_written t len;
       Pipe.write_without_pushback t.pipe data;
-      sent_result ())
+      sent_result () ~bytes:(len - Header.length))
   ;;
 
   let send_bin_prot_and_bigstring
-        t
-        (writer : _ Bin_prot.Type_class.writer)
-        x
-        ~buf
-        ~pos
-        ~len:payload_size
+    t
+    (writer : _ Bin_prot.Type_class.writer)
+    x
+    ~buf
+    ~pos
+    ~len:payload_size
     =
     check_closed t (fun () ->
       (* Write the size header manually and concatenate the two *)
@@ -234,14 +235,15 @@ module Pipe_writer (Data : DATA) = struct
       let dst_pos = writer.write data ~pos:Header.length x in
       Bigstring.blit ~src:buf ~src_pos:pos ~dst:data ~dst_pos ~len:payload_size;
       let data = Data.of_bigstring data in
-      incr_bytes_written t (Data.length data);
+      let len = Data.length data in
+      incr_bytes_written t len;
       Pipe.write_without_pushback t.pipe data;
-      sent_result ())
+      sent_result () ~bytes:(len - Header.length))
   ;;
 
   let send_bin_prot_and_bigstring_non_copying t writer x ~buf ~pos ~len =
     match send_bin_prot_and_bigstring t writer x ~buf ~pos ~len with
-    | Sent () -> sent_result Deferred.unit
+    | Sent { result = (); bytes } -> sent_result Deferred.unit ~bytes
     | (Closed | Message_too_big _) as r -> r
   ;;
 end
